@@ -12,7 +12,7 @@ use url::Url;
 #[derive(Debug, Snafu)]
 pub enum Error {
     HttpError {
-        source: ureq::Error,
+        source: crate::http::Error,
     },
     IoError {
         source: std::io::Error,
@@ -69,9 +69,8 @@ fn download_url(base_url: &Url, version: &Version, arch: &Arch) -> Url {
 
 pub fn extract_archive_into<P: AsRef<Path>>(
     path: P,
-    response: ureq::Response,
+    response: crate::http::Response,
 ) -> Result<(), Error> {
-    let response = response.into_reader();
     #[cfg(unix)]
     let extractor = archive::TarXz::new(response);
     #[cfg(windows)]
@@ -105,7 +104,7 @@ pub fn install_node_dist<P: AsRef<Path>>(
 
     let url = download_url(node_dist_mirror, version, arch);
     debug!("Going to call for {}", &url);
-    let response = ureq::get(url.as_str()).call().context(HttpError)?;
+    let response = crate::http::get(url.as_str()).context(HttpError)?;
 
     if response.status() == 404 {
         return Err(Error::VersionNotFound {
